# Examples

## file names

To facilitate automatic sorting in the documentation, a file naming
convention is set forth for the examples.  The convention is to prefix
the file names.

prefix   | type of example
------   | -------
``geo_`` | diffractometer geometry example
``how_`` | How-to guide
``var_`` | variation on a geometry
``tst_`` | tests or comparison

## notebook views

The examples can be viewed directly as notebooks in most web
browsers.  If an example fails to load properly, try using this
convenient web tool to view:

* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/geo_e4cv.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/geo_e6c.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/geo_k4cv.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/how_additional_parameters.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/how_extra_real_axis.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/tst_e4cv_fourc.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/tst_e6c_test_calculations.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/tst_UB_in_descriptor_document.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/var_e4cv_renamed_axes.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/var_engines.ipynb
* https://nbviewer.jupyter.org/github/bluesky/hklpy/blob/main/docs/source/examples/notebooks/var_nslsii_tardis.ipynb
